@@ -34,7 +34,7 @@ ColorLabel::ColorLabel(QWidget* parent, Qt::WindowFlags f)
     setFrameStyle(QFrame::Panel | QFrame::Sunken);
     setLineWidth(1);
     setFixedWidth(100);
-    setToolTip(tr("Click to change color."));
+    setToolTip(tr("Click to change color"));
     color_ = palette().color(QPalette::Window);
 }
 
