@@ -1,7 +1,7 @@
 /*
 * Copyright (c) Christian Surlykke
 *
-* This file is part of the LXQt project. <http://lxqt.org>
+* This file is part of the LXQt project. <https://lxqt-project.org>
 * It is distributed under the LGPL 2.1 or later license.
 * Please refer to the LICENSE file for a copy of the license, and
 * the AUTHORS file for copyright and authorship information.
@@ -188,7 +188,8 @@ bool MimetypeFilterItemModel::filterHelper(QModelIndex& source_index) const
         return true;
     }
 
-    foreach (const QString &pattern, mimeInfo->patterns())
+    const auto patterns = mimeInfo->patterns();
+    for (const QString &pattern : patterns)
     {
         if (pattern.contains(filterRegExp()))
         {
