@@ -25,6 +25,7 @@
 #include "mouseconfig.h"
 #include "keyboardconfig.h"
 #include "../liblxqt-config-cursor/selectwnd.h"
+#include "../lxqt-config-appearance/configothertoolkits.h"
 #include "keyboardlayoutconfig.h"
 
 #ifdef WITH_TOUCHPAD
@@ -72,12 +73,6 @@ int main(int argc, char** argv) {
     }
 #endif
 
-    if (QGuiApplication::platformName() == QLatin1String("wayland"))
-    { // Show a message dialog under wayland if no options are given.
-        QMessageBox::warning(nullptr, QObject::tr("Platform Unsupported"), waylandMsg);
-        return 0;
-    }
-
     LXQt::ConfigDialog dlg(QObject::tr("Keyboard and Mouse Settings"), &settings);
     dlg.setButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close|QDialogButtonBox::Reset);
     dlg.enableButton(QDialogButtonBox::Apply, false); // disable Apply button in the beginning
@@ -85,6 +80,15 @@ int main(int argc, char** argv) {
 
     LXQt::Settings qtSettings(QStringLiteral("lxqt"));
 
+    LXQt::Settings configAppearanceSettings(QStringLiteral("lxqt-config-appearance"));
+    ConfigOtherToolKits *configOtherToolKits = nullptr;
+    bool controlGTK(configAppearanceSettings.value(QStringLiteral("ControlGTKThemeEnabled")).toBool());
+    if (controlGTK)
+    {
+        configOtherToolKits = new ConfigOtherToolKits(&qtSettings, &configAppearanceSettings, &dlg);
+        configOtherToolKits->startXsettingsd();
+    }
+
     /*** Mouse Config ***/
     MouseConfig* mouseConfig = new MouseConfig(&settings, &qtSettings, &dlg);
     dlg.addPage(mouseConfig, QObject::tr("Mouse"), QStringLiteral("input-mouse"));
@@ -100,6 +104,8 @@ int main(int argc, char** argv) {
     QObject::connect(cursorConfig, &SelectWnd::settingsChanged, &dlg, [&dlg] {
         dlg.enableButton(QDialogButtonBox::Apply, true);
     });
+    if (!controlGTK)
+        cursorConfig->showExtraInfo(QStringLiteral("\n") + QObject::tr("To apply the changes also to GTK, check LXQt Appearance Configuration → GTK Style."));
 
     /*** Keyboard Config ***/
     KeyboardConfig* keyboardConfig = new KeyboardConfig(&settings, &qtSettings, &dlg);
@@ -110,21 +116,29 @@ int main(int argc, char** argv) {
     });
 
     /*** Keyboard Layout ***/
-    KeyboardLayoutConfig* keyboardLayoutConfig = new KeyboardLayoutConfig(&settings, &dlg);
-    dlg.addPage(keyboardLayoutConfig, QObject::tr("Keyboard Layout"), QStringLiteral("input-keyboard"));
-    QObject::connect(&dlg, &LXQt::ConfigDialog::reset, keyboardLayoutConfig, &KeyboardLayoutConfig::reset);
-    QObject::connect(keyboardLayoutConfig, &KeyboardLayoutConfig::settingsChanged, &dlg, [&dlg] {
-        dlg.enableButton(QDialogButtonBox::Apply, true);
-    });
+    KeyboardLayoutConfig* keyboardLayoutConfig = nullptr;
+    if (QGuiApplication::platformName() == QLatin1String("xcb"))
+    {
+        keyboardLayoutConfig = new KeyboardLayoutConfig(&settings, &dlg);
+        dlg.addPage(keyboardLayoutConfig, QObject::tr("Keyboard Layout"), QStringLiteral("input-keyboard"));
+        QObject::connect(&dlg, &LXQt::ConfigDialog::reset, keyboardLayoutConfig, &KeyboardLayoutConfig::reset);
+        QObject::connect(keyboardLayoutConfig, &KeyboardLayoutConfig::settingsChanged, &dlg, [&dlg] {
+            dlg.enableButton(QDialogButtonBox::Apply, true);
+        });
+    }
 
 #ifdef WITH_TOUCHPAD
-    /*** Touchpad Config ***/
-    TouchpadConfig* touchpadConfig = new TouchpadConfig(&settings, &dlg);
-    dlg.addPage(touchpadConfig, QObject::tr("Mouse and Touchpad"), QStringLiteral("input-tablet"));
-    QObject::connect(&dlg, &LXQt::ConfigDialog::reset, touchpadConfig, &TouchpadConfig::reset);
-    QObject::connect(touchpadConfig, &TouchpadConfig::settingsChanged, &dlg, [&dlg] {
-        dlg.enableButton(QDialogButtonBox::Apply, true);
-    });
+    TouchpadConfig* touchpadConfig = nullptr;
+    if (QGuiApplication::platformName() == QLatin1String("xcb"))
+    {
+        /*** Touchpad Config ***/
+        touchpadConfig = new TouchpadConfig(&settings, &dlg);
+        dlg.addPage(touchpadConfig, QObject::tr("Mouse and Touchpad"), QStringLiteral("input-tablet"));
+        QObject::connect(&dlg, &LXQt::ConfigDialog::reset, touchpadConfig, &TouchpadConfig::reset);
+        QObject::connect(touchpadConfig, &TouchpadConfig::settingsChanged, &dlg, [&dlg] {
+            dlg.enableButton(QDialogButtonBox::Apply, true);
+        });
+    }
 #endif
 
     // apply all changes on clicking Apply
@@ -133,10 +147,23 @@ int main(int argc, char** argv) {
         {
             mouseConfig->applyConfig();
             cursorConfig->applyCusorTheme();
+            if (configOtherToolKits)
+            {
+                // GTK3
+                configOtherToolKits->setGTKConfig(QStringLiteral("3.0"));
+                if(QGuiApplication::platformName() == QStringLiteral("wayland"))
+                    configOtherToolKits->setGsettingsConfig(QStringLiteral("3.0"));
+                // GTK2
+                configOtherToolKits->setGTKConfig(QStringLiteral("2.0"));
+                // Update xsettingsd
+                configOtherToolKits->setXSettingsConfig();
+            }
             keyboardConfig->applyConfig();
-            keyboardLayoutConfig->applyConfig();
+            if (keyboardLayoutConfig)
+                keyboardLayoutConfig->applyConfig();
 #ifdef WITH_TOUCHPAD
-            touchpadConfig->applyConfig();
+            if (touchpadConfig)
+                touchpadConfig->applyConfig();
 #endif
             // disable Apply button after changes are applied
             dlg.enableButton(btn, false);
