@@ -58,6 +58,14 @@ MouseConfig::MouseConfig(LXQt::Settings* _settings, QSettings* _qtSettings, QWid
   connect(ui.doubleClickInterval, QOverload<int>::of(&QSpinBox::valueChanged), this, &MouseConfig::settingsChanged);
   connect(ui.wheelScrollLines, QOverload<int>::of(&QSpinBox::valueChanged), this, &MouseConfig::settingsChanged);
   connect(ui.singleClick, &QAbstractButton::clicked, this, &MouseConfig::settingsChanged);
+
+  if (QGuiApplication::platformName() == QLatin1String("wayland"))
+  { // disable the settings that don't work under Wayland and show the extra info
+    ui.mouseLeftHanded->setEnabled(false);
+    ui.extraInfoLabel->setText(QStringLiteral("\n") + tr("Use the settings of the Wayland compositor for more options about mouse, touchpad and keyboard."));
+  }
+  else
+    ui.extraInfoLabel->hide();
 }
 
 MouseConfig::~MouseConfig() {
