@@ -58,7 +58,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="130"/>
         <source>Type in the following box to test your keyboard settings</source>
-        <translation>在下列方框裡輸入文字測試你的鍵盤設定</translation>
+        <translation>在下列方框裡輸入文字測試您的鍵盤設定</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="76"/>
@@ -69,7 +69,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="167"/>
         <source>Turn on NumLock after login</source>
-        <translation>登入後自動開啟NumLock</translation>
+        <translation>登入後自動開用 NumLock</translation>
     </message>
 </context>
 <context>
@@ -77,17 +77,17 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="20"/>
         <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
-        <translation>&lt;b&gt;鍵盤布局&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;鍵盤配置&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="48"/>
         <source>Layout</source>
-        <translation>布局</translation>
+        <translation>配置</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="53"/>
         <source>Variant</source>
-        <translation>變形</translation>
+        <translation>變異</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="63"/>
@@ -112,12 +112,12 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="108"/>
         <source>Keyboard model:</source>
-        <translation>鍵盤模型：</translation>
+        <translation>鍵盤型號：</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="122"/>
         <source>Keys to change layout:</source>
-        <translation>切換布局的按鍵：</translation>
+        <translation>按鍵用於變更配置：</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="133"/>
@@ -127,7 +127,7 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="141"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;注意&lt;/span&gt;：如果你正在使用像是IBus、uim、fcitx或gcin的&lt;span style=&quot; font-weight:600;&quot;&gt;輸入模式&lt;/span&gt;，這裡的設定&lt;span style=&quot; font-weight:600;&quot;&gt;可能無效&lt;/span&gt;，因為它們可能被輸入模式覆寫了。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;注意&lt;/span&gt;：如果您正在使用的&lt;span style=&quot; font-weight:600;&quot;&gt;輸入法&lt;/span&gt;，像是 IBus、uim、fcitx 或 gcin 輸入，於此設定&lt;span style=&quot; font-weight:600;&quot;&gt;可能無法運作&lt;/span&gt;，因為它們可能被輸入法所覆寫。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -165,50 +165,57 @@
     <message>
         <location filename="../mouseconfig.ui" line="57"/>
         <source>Single click to activate items</source>
-        <translation>點一下選取物件</translation>
+        <translation>點按一下啟動項目</translation>
+    </message>
+    <message>
+        <location filename="../mouseconfig.cpp" line="65"/>
+        <source>Use the settings of the Wayland compositor for more options about mouse, touchpad and keyboard.</source>
+        <translation>使用 Wayland 合成器的設定來用於有關滑鼠、觸控板和鍵盤的更多選項。</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="77"/>
-        <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="38"/>
+        <location filename="../lxqt-config-input.cpp" line="39"/>
         <source>LXQt input settings are currently unsupported under Wayland.
 
 Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt 輸入設定目前在 Wayland 下尚未支援。
+
+滑鼠、觸控板及鍵盤可以在合成器設定中進行設定。</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="81"/>
+        <location filename="../lxqt-config-input.cpp" line="76"/>
         <source>Keyboard and Mouse Settings</source>
         <translation>鍵盤和滑鼠設定</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="90"/>
+        <location filename="../lxqt-config-input.cpp" line="94"/>
         <source>Mouse</source>
         <translation>滑鼠</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="99"/>
+        <location filename="../lxqt-config-input.cpp" line="103"/>
         <source>Cursor</source>
         <translation>游標</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="106"/>
+        <location filename="../lxqt-config-input.cpp" line="108"/>
+        <source>To apply the changes also to GTK, check LXQt Appearance Configuration → GTK Style.</source>
+        <translation>要將變更套用也用於 GTK，勾選 LXQt 外觀 設定 → GTK 樣式。</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="112"/>
         <source>Keyboard</source>
         <translation>鍵盤</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="114"/>
+        <location filename="../lxqt-config-input.cpp" line="123"/>
         <source>Keyboard Layout</source>
-        <translation>鍵盤布局</translation>
+        <translation>鍵盤配置</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="123"/>
+        <location filename="../lxqt-config-input.cpp" line="136"/>
         <source>Mouse and Touchpad</source>
         <translation>滑鼠及觸控版</translation>
     </message>
@@ -218,17 +225,17 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
         <source>Select a keyboard layout</source>
-        <translation>選擇鍵盤布局</translation>
+        <translation>選擇鍵盤配置</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
         <source>Keyboard layout</source>
-        <translation>鍵盤布局</translation>
+        <translation>鍵盤配置</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
         <source>Variant</source>
-        <translation>變形</translation>
+        <translation>變異</translation>
     </message>
 </context>
 <context>
@@ -251,7 +258,7 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../touchpadconfig.ui" line="60"/>
         <source>Tap to click</source>
-        <translation>輕觸以點擊</translation>
+        <translation>輕觸點按</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="67"/>
@@ -261,7 +268,7 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../touchpadconfig.ui" line="74"/>
         <source>Tap and drag</source>
-        <translation>輕觸然後拖曳</translation>
+        <translation>點按拖放</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="86"/>
@@ -304,8 +311,8 @@ Otherwise you can get rid of this message by changing xinput driver to &quot;lib
         <translation>LXQt 僅支援以 &quot;libinput&quot; 作為 xinput 的驅動。
 (目前是： %1)
 
-如果您真的想這樣做，請手動設定 xinput 。
-否則請把 xinput 驅動設定為 &quot;libinput&quot; 來隱藏這個訊息。
+如果確定要這樣做，請手動設定 xinput 。
+否則可以把 xinput 驅動設定為 &quot;libinput&quot; 來隱藏這個訊息。
 </translation>
     </message>
 </context>
