@@ -56,7 +56,15 @@ MonitorSettingsDialog::MonitorSettingsDialog() :
             operation->deleteLater();
         }
         else if(configOp && !configOp->config()) {
-            qDebug() << "Error: Config is invalid, probably backend couldn't load";
+            // Show info under wlroots based compositors
+            if (QGuiApplication::platformName() == QLatin1String("wayland")) {
+                QMessageBox::warning(this,
+                                     tr("Platform Unsupported"),
+                                     tr("LXQt monitor settings are currently unsupported under this wayland compositor.\n\nYou can configure your monitor(s) with kanshi."));
+            }
+            else {
+                qDebug() << "Error: Config is invalid, probably backend couldn't load";
+            }
             exit(1);
         }
         else if(configOp && configOp->config() && !configOp->config()->screen()) {
@@ -79,6 +87,10 @@ MonitorSettingsDialog::MonitorSettingsDialog() :
     });
 
     connect(ui.settingsButton, &QToolButton::clicked, this, &MonitorSettingsDialog::showSettingsDialog);
+
+    // also make sure that widgets are shown completely (a Qt bug under Wayland?)
+    LXQt::Settings settings(QStringLiteral("lxqt-config-monitor"));
+    resize(sizeHint().expandedTo(settings.value(QStringLiteral("size")).toSize().expandedTo(QSize(600, 400))));
 }
 
 MonitorSettingsDialog::~MonitorSettingsDialog()
@@ -138,7 +150,6 @@ void MonitorSettingsDialog::loadConfiguration(KScreen::ConfigPtr config)
         monitorPicture->setScene(monitors);
 
     ui.monitorList->setCurrentRow(0);
-    adjustSize();
 }
 
 void MonitorSettingsDialog::applyConfiguration(bool saveConfigOk)
@@ -152,12 +163,13 @@ void MonitorSettingsDialog::applyConfiguration(bool saveConfigOk)
 
 void MonitorSettingsDialog::accept()
 {
-    //applyConfiguration(true);
+    saveSize();
     QDialog::accept();
 }
 
 void MonitorSettingsDialog::reject()
 {
+    saveSize();
     QDialog::reject();
 }
 
@@ -229,3 +241,9 @@ void MonitorSettingsDialog::showSettingsDialog()
     SettingsDialog settingsDialog(tr("Advanced settings"), &settings, mConfig);
     settingsDialog.exec();
 }
+
+void MonitorSettingsDialog::saveSize()
+{
+    LXQt::Settings settings(QStringLiteral("lxqt-config-monitor"));
+    settings.setValue(QStringLiteral("size"), size());
+}
