@@ -11,22 +11,22 @@
     <message>
         <location filename="../fastmenu.ui" line="40"/>
         <source> ❶ ❷ Extended view</source>
-        <translation> ❶ ❷ 延伸螢幕</translation>
+        <translation> ❶ ❷ 延伸檢視</translation>
     </message>
     <message>
         <location filename="../fastmenu.ui" line="45"/>
         <source> ❶ ❶ Unified view</source>
-        <translation> ❶ ❶ 同步螢幕</translation>
+        <translation> ❶ ❶ 同步檢視</translation>
     </message>
     <message>
         <location filename="../fastmenu.ui" line="50"/>
         <source> ❶     Only first</source>
-        <translation> ❶     僅顯示第一螢幕</translation>
+        <translation> ❶     僅顯示第一個</translation>
     </message>
     <message>
         <location filename="../fastmenu.ui" line="55"/>
         <source>     ❷ Only second</source>
-        <translation>     ❷ 僅顯示第二螢幕</translation>
+        <translation>     ❷ 僅顯示第二個</translation>
     </message>
 </context>
 <context>
@@ -34,23 +34,24 @@
     <message>
         <location filename="../loadsettings.cpp" line="97"/>
         <source>Default monitor settings applied.</source>
-        <translation type="unfinished"></translation>
+        <translation>預設顯示器設定已經套用。</translation>
     </message>
     <message>
         <location filename="../loadsettings.cpp" line="98"/>
         <source>Adjust your screens with LXQt Monitor Settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>使用 LXQt 顯示器設定來調整螢幕。</translation>
     </message>
     <message>
         <location filename="../loadsettings.cpp" line="107"/>
         <source>lxqt-config-monitor: Settings applied.</source>
-        <translation type="unfinished"></translation>
+        <translation>lxqt-config-monitor：設定已經套用。</translation>
     </message>
     <message>
         <location filename="../loadsettings.cpp" line="109"/>
         <source>lxqt-config-monitor: Settings not applied.
 If this is a Wayland compositor, you could try kanshi to configure your monitor(s).</source>
-        <translation type="unfinished"></translation>
+        <translation>lxqt-config-monitor：設定並未套用。
+如果這是 Wayland 合成器，您可以嘗試 kanshi 來設定顯示器。</translation>
     </message>
 </context>
 <context>
@@ -63,7 +64,7 @@ If this is a Wayland compositor, you could try kanshi to configure your monitor(
     <message>
         <location filename="../managesavedsettings.ui" line="27"/>
         <source>Saved settings</source>
-        <translation>儲存設定</translation>
+        <translation>已經儲存設定</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.ui" line="45"/>
@@ -120,14 +121,16 @@ If this is a Wayland compositor, you could try kanshi to configure your monitor(
     <message>
         <location filename="../managesavedsettings.cpp" line="172"/>
         <source>Settings Activation Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>設定啟用失敗</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.cpp" line="173"/>
         <source>Selected settings cannot be applied with currently active monitors.
 
 Please choose from the highlighted configurations.</source>
-        <translation type="unfinished"></translation>
+        <translation>所選的設定不可套用於目前作用的顯示器。
+
+請由強調顯示的設定項目來進行選擇。</translation>
     </message>
 </context>
 <context>
@@ -153,14 +156,16 @@ Please choose from the highlighted configurations.</source>
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="62"/>
         <source>Platform Unsupported</source>
-        <translation type="unfinished"></translation>
+        <translation>非支援的平台</translation>
     </message>
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="63"/>
         <source>LXQt monitor settings are currently unsupported under this wayland compositor.
 
 You can configure your monitor(s) with kanshi.</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt 顯示器設定在此 Wayland 合成器下目前並未支援。
+
+您可以使用 kanshi 來設定顯示器。</translation>
     </message>
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="118"/>
@@ -203,17 +208,17 @@ You can configure your monitor(s) with kanshi.</source>
     <message>
         <location filename="../monitorwidget.ui" line="27"/>
         <source>Enable this display</source>
-        <translation>啟用這個螢幕</translation>
+        <translation>啟用這個顯示</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="49"/>
         <source>This is my primary display</source>
-        <translation>這是我的主螢幕</translation>
+        <translation>這是我的主要顯示</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="54"/>
         <source>This screen extends another display</source>
-        <translation>此螢幕延伸自另一個螢幕</translation>
+        <translation>此螢幕延伸另一個顯示</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="125"/>
@@ -251,21 +256,21 @@ You can configure your monitor(s) with kanshi.</source>
         <location filename="../monitorwidget.cpp" line="130"/>
         <source>Vendor: %1
 </source>
-        <translation>發行商： %1
+        <translation>廠商： %1
 </translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="131"/>
         <source>Serial: %1
 </source>
-        <translation>序號： %1
+        <translation>系列： %1
 </translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="132"/>
         <source>Display size: %1cm x %2cm
 </source>
-        <translation>顯示大小： %1公分 x %2公分
+        <translation>顯示大小： %1cm x %2cm
 </translation>
     </message>
     <message>
@@ -305,7 +310,7 @@ You can configure your monitor(s) with kanshi.</source>
     <message>
         <location filename="../monitorwidget.cpp" line="248"/>
         <source>%1 Hz</source>
-        <translation>%1 赫茲</translation>
+        <translation>%1 Hz</translation>
     </message>
 </context>
 <context>
@@ -313,7 +318,7 @@ You can configure your monitor(s) with kanshi.</source>
     <message>
         <location filename="../settingsdialog.cpp" line="33"/>
         <source>Manage Saved Settings</source>
-        <translation>管理儲存的設定</translation>
+        <translation>管理已經儲存的設定</translation>
     </message>
 </context>
 <context>
@@ -334,12 +339,12 @@ You can configure your monitor(s) with kanshi.</source>
     <message>
         <location filename="../timeoutdialog.ui" line="14"/>
         <source>Settings are changed</source>
-        <translation>設定已更改</translation>
+        <translation>設定已經變更</translation>
     </message>
     <message>
         <location filename="../timeoutdialog.ui" line="46"/>
         <source>Are the current settings OK for you?</source>
-        <translation>現在的設定是否合適？</translation>
+        <translation>目前的設定是否適用？</translation>
     </message>
     <message numerus="yes">
         <location filename="../timeoutdialog.cpp" line="63"/>
